@@ -116,6 +116,9 @@ AppWindow::AppWindow(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>&
   m_menubar->show();
   m_pBoxTop->pack_start(*m_menubar, Gtk::PACK_SHRINK);
 
+  //TODO: Remove our use of add_accelerator() in application.cc,
+  //if there is ever an easier way to make the 'accel's from the .glade file just work.
+  //See https://bugzilla.gnome.org/show_bug.cgi?id=708905
 
   add_mime_type("application/x-glom"); //TODO: make this actually work - we need to register it properly.
 
@@ -123,11 +126,13 @@ AppWindow::AppWindow(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>&
 #ifndef G_OS_WIN32
   //Install UI hooks for this:
   ConnectionPool* connection_pool = ConnectionPool::get_instance();
-  if(!connection_pool)
+  if(connection_pool)
+  {
     connection_pool->set_avahi_publish_callbacks(
       sigc::mem_fun(*this, &AppWindow::on_connection_avahi_begin),
       sigc::mem_fun(*this, &AppWindow::on_connection_avahi_progress),
       sigc::mem_fun(*this, &AppWindow::on_connection_avahi_done) );
+  }
 #endif
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
@@ -286,7 +291,8 @@ void AppWindow::init_menus_file()
   m_listDeveloperActions.push_back(action_print_edit);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  m_refActionGroup_File->add_action("close",
+  //Add to the window's regular "win" ActionMap:
+  add_action("close",
     sigc::mem_fun((GlomBakery::AppWindow_WithDoc&)*this, &GlomBakery::AppWindow_WithDoc::on_menu_file_close));
 
   insert_action_group("file", m_refActionGroup_File);
@@ -458,11 +464,28 @@ void AppWindow::on_menu_help_about()
     vecAuthors.push_back("Murray Cumming <murrayc@murrayc.com>");
     m_pAbout->set_authors(vecAuthors);
     
-    Glib::RefPtr<Gdk::Pixbuf> logo = Gdk::Pixbuf::create_from_file(GLOM_ICONPATH);
+    //For some reason this use of the resource:// syntax does not work:
+    const char* about_icon_name = "48x48/glom.png";
+    //const Glib::ustring glom_icon_path = "resource://" + Utils::get_icon_path(about_icon_name);
+    //Glib::RefPtr<Gdk::Pixbuf> logo = Gdk::Pixbuf::create_from_file(glom_icon_path);
+
+    const Glib::ustring glom_icon_path = Utils::get_icon_path(about_icon_name);
+
+    //TODO: Use this, instead of the C API, when we can depend on gtkmm 3.12, with a try/catch:
+    //Glib::RefPtr<Gdk::Pixbuf> logo = Gdk::Pixbuf::create_from_resource(glom_icon_path);
+    GError* gerror = 0;
+    Glib::RefPtr<Gdk::Pixbuf> logo =
+      Glib::wrap(gdk_pixbuf_new_from_resource(glom_icon_path.c_str(), &gerror));
+    if(gerror)
+    {
+      std::cerr << G_STRFUNC << ": Could not load icon from resource path=" << glom_icon_path << std::endl;
+      g_clear_error(&gerror);
+    }
+
     if(logo)
       m_pAbout->set_logo(logo);
     else
-      std::cout << G_STRFUNC << ": Could not load icon from path=" << GLOM_ICONPATH << std::endl;
+      std::cout << G_STRFUNC << ": Could not load icon from resource path=" << glom_icon_path << std::endl;
 
     m_pAbout->signal_hide().connect( sigc::mem_fun(*this, &AppWindow::on_about_close) );
     m_bAboutShown = true;
@@ -576,6 +599,12 @@ void AppWindow::open_browsed_document(const EpcServiceInfo* server, const Glib::
     Dialog_Connection* dialog_connection = 0;
     //Load the Glade file and instantiate its widgets to get the dialog stuff:
     Utils::get_glade_widget_derived_with_warning(dialog_connection);
+    if(!dialog_connection)
+    {
+      std::cerr << G_STRFUNC << ": dialog_connection is null." << std::endl;
+      return;
+    }
+
     dialog_connection->set_transient_for(*this);
     dialog_connection->set_connect_to_browsed();
     dialog_connection->set_database_name(service_name);
@@ -658,7 +687,7 @@ void AppWindow::open_browsed_document(const EpcServiceInfo* server, const Glib::
     }
     else
     {
-      std::cerr << "Could not parse the document that was retrieved over the network: failure_code=" << failure_code << std::endl;
+      std::cerr << G_STRFUNC << ": Could not parse the document that was retrieved over the network: failure_code=" << failure_code << std::endl;
     }
 
     g_free(document_contents);
@@ -1094,7 +1123,7 @@ bool AppWindow::on_document_load()
 
     if(!error_message.empty())
     {
-      std::cerr << "Python Error: " << error_message << std::endl;
+      std::cerr << G_STRFUNC << ": Python Error: " << error_message << std::endl;
     }
   }
 
@@ -1415,20 +1444,26 @@ void AppWindow::existing_or_new_new()
 
 void AppWindow::set_mode_data()
 {
-  if (!m_pFrame)
+  if(!m_pFrame)
     return;
 
-  if (m_pFrame->m_Mode == Frame_Glom::MODE_Find)
-    m_action_mode_find->change_state(true);
+  //Update the visual feedback in the menu.
+  //This doesn't trigger the activate signal:
+  m_action_mode_find->change_state(false);
+
+  m_pFrame->set_mode_data();
 }
 
 void AppWindow::set_mode_find()
 {
-  if (!m_pFrame)
+  if(!m_pFrame)
     return;
 
-  if (m_pFrame->m_Mode == Frame_Glom::MODE_Data)
-    m_action_mode_find->change_state(true);
+  //Update the visual feedback in the menu.
+  //This doesn't trigger the activate signal:
+  m_action_mode_find->change_state(true);
+
+  m_pFrame->set_mode_find();
 }
 
 void AppWindow::on_menu_help_contents()
@@ -1618,7 +1653,7 @@ bool AppWindow::recreate_database_from_example(bool& user_cancelled)
     //}
     //catch(const std::exception& ex)
     //{
-    //  std::cerr << "AppWindow::recreate_database_from_example(): exception: " << ex.what() << std::endl;
+    //  std::cerr << G_STRFUNC << ": AppWindow::recreate_database_from_example(): exception: " << ex.what() << std::endl;
       //HandleError(ex);
     //}
 
@@ -1712,12 +1747,13 @@ bool AppWindow::recreate_database_from_backup(const Glib::ustring& backup_uri, b
   {
     std::cerr << G_STRFUNC << ": Gnome::Gda::Connection::create_database(" << db_name << ") failed: " << ex.what() << std::endl;
 
-    //Tell the user:
-    Gtk::Dialog* dialog = 0;
-    Utils::get_glade_widget_with_warning("glom_developer.glade", "dialog_error_create_database", dialog);
-    dialog->set_transient_for(*this);
-    Glom::Utils::dialog_run_with_help(dialog, "dialog_error_create_database");
-    delete dialog;
+
+    const Glib::ustring message = _("Glom could not create the new database. Maybe you do not have the necessary access rights. Please contact your system administrator.");
+    Gtk::MessageDialog dialog(Utils::bold_message(_("Database Creation Failed")), true, Gtk::MESSAGE_ERROR );
+    dialog.set_secondary_text(message);
+    dialog.set_transient_for(*this);
+
+    dialog.run();
 
     return false;
   }
@@ -2773,13 +2809,13 @@ void AppWindow::init_menus_edit()
   //Build actions:
   m_refActionGroup_Edit = Gio::SimpleActionGroup::create();
 
-  m_refActionGroup_Edit->add_action("cut",
+  add_action("cut",
     sigc::mem_fun((AppWindow&)*this, &AppWindow::on_menu_edit_cut_activate));
-  m_refActionGroup_Edit->add_action("copy",
+  add_action("copy",
     sigc::mem_fun((AppWindow&)*this, &AppWindow::on_menu_edit_copy_activate));
-  m_refActionGroup_Edit->add_action("paste",
+  add_action("paste",
     sigc::mem_fun((AppWindow&)*this, &AppWindow::on_menu_edit_paste_activate));
-  m_refActionGroup_Edit->add_action("clear");
+  add_action("clear");
     //TODO? sigc::mem_fun((AppWindow&)*this, &AppWindow::on_menu_edit_clear_activate));
 
   //We remember this action, so that it can be explicitly activated later.
@@ -2985,9 +3021,13 @@ void AppWindow::on_menu_edit_find()
   //The state is not changed automatically:
   bool active = false;
   m_action_mode_find->get_state(active);
-  m_action_mode_find->change_state(!active);
+  active = !active;
+  m_action_mode_find->change_state(active);
 
-  m_pFrame->on_menu_Edit_Find();
+  if(active)
+    m_pFrame->set_mode_find();
+  else
+    m_pFrame->set_mode_data();
 }
 
 
