@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
@@ -117,7 +117,7 @@ sharedptr<SharedConnection> Base_DB::connect_to_server(Gtk::Window* parent_windo
 
 void Base_DB::handle_error(const Glib::Exception& ex)
 {
-  std::cerr << "Internal Error (Base_DB::handle_error()): exception type=" << typeid(ex).name() << ", ex.what()=" << ex.what() << std::endl;
+  std::cerr << G_STRFUNC << ": Internal Error (Base_DB::handle_error()): exception type=" << typeid(ex).name() << ", ex.what()=" << ex.what() << std::endl;
 
   Gtk::MessageDialog dialog(Utils::bold_message(_("Internal error")), true, Gtk::MESSAGE_WARNING );
   dialog.set_secondary_text(ex.what());
@@ -127,7 +127,7 @@ void Base_DB::handle_error(const Glib::Exception& ex)
 
 void Base_DB::handle_error(const std::exception& ex)
 {
-  std::cerr << "Internal Error (Base_DB::handle_error()): exception type=" << typeid(ex).name() << ", ex.what()=" << ex.what() << std::endl;
+  std::cerr << G_STRFUNC << ": Internal Error (Base_DB::handle_error()): exception type=" << typeid(ex).name() << ", ex.what()=" << ex.what() << std::endl;
 
   Gtk::MessageDialog dialog(Utils::bold_message(_("Internal error")), true, Gtk::MESSAGE_WARNING );
   dialog.set_secondary_text(ex.what());
@@ -313,7 +313,7 @@ Glib::RefPtr<Gnome::Gda::Connection> Base_DB::get_connection()
   {
      sharedconnection = connect_to_server();
   }
-  catch (const Glib::Error& error)
+  catch(const Glib::Error& error)
   {
     std::cerr << G_STRFUNC << ": " << error.what() << std::endl;
   }
