@@ -42,7 +42,7 @@
 #include <glom/mode_design/dialog_add_related_table.h>
 #include <glom/mode_design/script_library/dialog_script_library.h>
 #include <glom/mode_design/dialog_initial_password.h>
-#include <glom/mode_design/relationships_overview/dialog_relationships_overview.h>
+#include <glom/mode_design/relationships_overview/window_relationships_overview.h>
 #include <glom/glade_utils.h>
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
@@ -93,7 +93,7 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
   m_pDialog_Fields(0),
   m_pDialog_Relationships(0),
   m_dialog_addrelatedtable(0),
-  m_dialog_relationships_overview(0),
+  m_window_relationships_overview(0),
 #endif // !GLOM_ENABLE_CLIENT_ONLY
   m_pDialogConnection(0)
 {
@@ -129,7 +129,8 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
 
   PlaceHolder* placeholder_quickfind = 0;
   builder->get_widget_derived("vbox_quickfind", placeholder_quickfind);
-  placeholder_quickfind->add(*m_pBox_QuickFind);
+  if(placeholder_quickfind)
+    placeholder_quickfind->add(*m_pBox_QuickFind);
 
   //Add the Records/Found widgets at the right of the notebook tabs:
   m_Box_RecordsCount.pack_start(
@@ -227,11 +228,11 @@ Frame_Glom::~Frame_Glom()
     m_dialog_addrelatedtable = 0;
   }
 
-  if(m_dialog_relationships_overview)
+  if(m_window_relationships_overview)
   {
-    remove_view(m_dialog_relationships_overview);
-    delete m_dialog_relationships_overview;
-    m_dialog_relationships_overview = 0;
+    remove_view(m_window_relationships_overview);
+    delete m_window_relationships_overview;
+    m_window_relationships_overview = 0;
   }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 }
@@ -263,17 +264,22 @@ void Frame_Glom::set_mode_widget(Gtk::Widget& widget)
   //and I don't see a way to get a list of children.
 
   AppWindow* pApp = dynamic_cast<AppWindow*>(get_app_window());
-  if(pApp)
-  {
-    Notebook_Glom* notebook_current = dynamic_cast<Notebook_Glom*>(m_pBox_Mode->get_child());
-    if(notebook_current)
-    {
-      m_pBox_Mode->remove();
-    }
+  if(!pApp)
+    return;
 
-    m_pBox_Mode->add(widget);
-    widget.show();
+  Notebook_Glom* notebook_current = dynamic_cast<Notebook_Glom*>(m_pBox_Mode->get_child());
+  if(notebook_current == &widget)
+  {
+    return; //No change necessary.
   }
+
+  if(notebook_current)
+  {
+    m_pBox_Mode->remove();
+  }
+
+  m_pBox_Mode->add(widget);
+  widget.show();
 }
 
 bool Frame_Glom::set_mode(enumModes mode)
@@ -308,6 +314,13 @@ bool Frame_Glom::set_mode(enumModes mode)
     m_pBox_QuickFind->hide();
   }
 
+
+  //Show the main part of the UI:
+  if(m_Mode == MODE_Find)
+    set_mode_widget(m_Notebook_Find);
+  else
+    set_mode_widget(m_Notebook_Data);
+
   return changed;
 }
 
@@ -375,7 +388,7 @@ void Frame_Glom::show_table_allow_empty(const Glib::ustring& table_name, const G
       {
         sharedptr<Field> field_primary_key = get_field_primary_key_for_table(m_table_name);
         if(field_primary_key)
-      {
+        {
           sharedptr<LayoutItem_Field> layout_item_sort = sharedptr<LayoutItem_Field>::create();
           layout_item_sort->set_full_field_details(field_primary_key);
 
@@ -426,8 +439,11 @@ void Frame_Glom::show_table_allow_empty(const Glib::ustring& table_name, const G
   show_table_title();
 
   //List the reports and print layouts in the menus:
-  pApp->fill_menu_reports(table_name);
-  pApp->fill_menu_print_layouts(table_name);
+  if(pApp)
+  {
+    pApp->fill_menu_reports(table_name);
+    pApp->fill_menu_print_layouts(table_name);
+  }
 
   //show_all();
 }
@@ -690,7 +706,7 @@ void Frame_Glom::export_data_to_stream(std::ostream& the_stream, const FoundSet&
               size_t pos = field_text.find_first_of(newline_to_find);
               if(pos != std::string::npos)
               {
-                std::cerr << "export: binary data field text contains an unexpected newline: " << field_text << std::endl;
+                std::cerr << G_STRFUNC << ": export: binary data field text contains an unexpected newline: " << field_text << std::endl;
                 continue;
               }
 
@@ -698,7 +714,7 @@ void Frame_Glom::export_data_to_stream(std::ostream& the_stream, const FoundSet&
               pos = field_text.find_first_of(quote_to_find);
               if(pos != std::string::npos)
               {
-                std::cerr << "export: binary data field text contains an unexpected quote: " << field_text << std::endl;
+                std::cerr << G_STRFUNC << ": export: binary data field text contains an unexpected quote: " << field_text << std::endl;
                 continue;
               }
             }
@@ -761,23 +777,31 @@ void Frame_Glom::on_menu_file_import()
 
         Dialog_Import_CSV_Progress* progress_dialog = 0;
         Glom::Utils::get_glade_widget_derived_with_warning(progress_dialog);
-        add_view(progress_dialog);
+        int response = Gtk::RESPONSE_OK;
+        if(!progress_dialog)
+        {
+          std::cerr << G_STRFUNC << ": progress_dialog was null." << std::endl;
+        }
+        else
+        {
+          add_view(progress_dialog);
 
-        progress_dialog->init_db_details(dialog->get_target_table_name());
-        progress_dialog->import(*dialog);
-        const int response = progress_dialog->run();
+          progress_dialog->init_db_details(dialog->get_target_table_name());
+          progress_dialog->import(*dialog);
+          response = progress_dialog->run(); //TODO: Check response?
 
-        remove_view(progress_dialog);
-        delete progress_dialog;
-        progress_dialog = 0;
+          remove_view(progress_dialog);
+          delete progress_dialog;
+          progress_dialog = 0;
 
-        // Force update from database so the newly added entries are shown
-        show_table_refresh();
+          // Force update from database so the newly added entries are shown
+          show_table_refresh();
 
-        // Re-show chooser dialog when an error occured or when the user
-        // cancelled.
-        if(response == Gtk::RESPONSE_OK)
-          break;
+          // Re-show chooser dialog when an error occured or when the user
+          // cancelled.
+          if(response == Gtk::RESPONSE_OK)
+            break;
+        }
       }
 
       remove_view(dialog);
@@ -1013,18 +1037,9 @@ void Frame_Glom::set_enable_layout_drag_and_drop(bool enable)
 
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-void Frame_Glom::on_menu_Edit_Find()
+void Frame_Glom::set_mode_find()
 {
-  //Switch back to data mode if we are in find mode.
-  if(m_Mode == MODE_Find)
-  {
-    //Switch to data mode
-    if(set_mode(MODE_Data))
-      show_table(m_table_name);
-    return;
-  }
-
-  //Otherwise switch to find mode.
+  //Switch to find mode.
   //This can take quite a long time, flicking between 1 or 2 intermediate screens.
   //It shouldn't, but until we fix that, let's show the busy cursor while it's working:
   BusyCursor busy_cursor(get_app_window());
@@ -1051,6 +1066,17 @@ void Frame_Glom::on_menu_Edit_Find()
   }
 }
 
+void Frame_Glom::set_mode_data()
+{
+  //Switch to data mode
+  if(!set_mode(MODE_Data))
+    return;
+
+  //This would lose the current found set, if any:
+  //show_table(m_table_name);
+}
+
+
 void Frame_Glom::on_menu_add_record()
 {
   BusyCursor busy_cursor(get_app_window());
@@ -1300,7 +1326,8 @@ void Frame_Glom::on_notebook_find_criteria(const Gnome::Gda::SqlExpr& where_clau
     std::cerr << G_STRFUNC << ": get_app_window() failed." << std::endl;
     return;
   }
-  
+
+  //Identify the where_clause:
   Gnome::Gda::SqlExpr where_clause_to_use = where_clause;
 
   //Prefer the quick find text if any was entered:
@@ -1311,6 +1338,7 @@ void Frame_Glom::on_notebook_find_criteria(const Gnome::Gda::SqlExpr& where_clau
       Utils::get_find_where_clause_quick(get_document(), m_table_name, Gnome::Gda::Value(quickfind_criteria));
   }
 
+  //Warn if there was no find criteria:
   if(where_clause_to_use.empty())
   {
     const Glib::ustring message = _("You have not entered any find criteria. Try entering information in the fields.");
@@ -1324,37 +1352,46 @@ void Frame_Glom::on_notebook_find_criteria(const Gnome::Gda::SqlExpr& where_clau
 
   //std::cout << "debug: " << G_STRFUNC << ": " << where_clause << std::endl;
   
+
+  //Try to find some records with the where_clause:
   bool records_found = false;
 
   { //Extra scope, to control the lifetime of the busy cursor.
     BusyCursor busy_cursor(app);
 
-    app->set_mode_data();
-
     //std::cout << "Frame_Glom::on_notebook_find_criteria: where_clause=" << where_clause << std::endl;
     FoundSet found_set;
     found_set.m_table_name = m_table_name;
     found_set.m_where_clause = where_clause_to_use;
-    records_found = m_Notebook_Data.init_db_details(found_set);
+    const bool inited = m_Notebook_Data.init_db_details(found_set);
 
-    //std::cout << "debug: " << G_STRFUNC << ": BEFORE  m_Notebook_Data.select_page_for_find_results()" << std::endl;
     m_Notebook_Data.select_page_for_find_results();
-    //std::cout << "debug: " << G_STRFUNC << ": AFTER  m_Notebook_Data.select_page_for_find_results()" << std::endl;
+
+    //Show how many records were found:
+    records_found = (update_records_count() > 0);
+
+    if(!inited)
+      records_found = 0;
   }
 
+  std::cout << G_STRFUNC << ": records_found=" << records_found << std::endl;
+
   if(!records_found)
   {
     const bool find_again = Utils::show_warning_no_records_found(*app);
 
-    if(find_again)
-      app->set_mode_find();
-    else
+    if(!find_again)
+    {
+      //Go back to data mode, showing all records:
       on_button_find_all();
+      app->set_mode_data();
+    }
   }
   else
   {
-    //Show how many records were found:
-    update_records_count();
+    //Actually show the found data,
+    //and show that we are in data mode:
+    app->set_mode_data();
   }
 }
 
@@ -1576,22 +1613,21 @@ void Frame_Glom::do_menu_developer_fields(Gtk::Window& parent)
 
 void Frame_Glom::on_menu_developer_relationships_overview()
 {
-  if(!m_dialog_relationships_overview)
+  if(!m_window_relationships_overview)
   {
-    Utils::get_glade_widget_derived_with_warning(m_dialog_relationships_overview);
-    add_view(m_dialog_relationships_overview);
+    Utils::get_glade_widget_derived_with_warning(m_window_relationships_overview);
+    add_view(m_window_relationships_overview);
+
+    m_window_relationships_overview->signal_hide().connect( sigc::mem_fun(*this, &Frame_Glom::on_developer_dialog_hide));
+    add_window_to_app(m_window_relationships_overview);
   }
 
-  if(m_dialog_relationships_overview)
+  if(m_window_relationships_overview)
   {
-    m_dialog_relationships_overview->set_transient_for(*(get_app_window()));
-    m_dialog_relationships_overview->load_from_document();
+    m_window_relationships_overview->set_transient_for(*(get_app_window()));
+    m_window_relationships_overview->load_from_document();
 
-    Glom::Utils::dialog_run_with_help(m_dialog_relationships_overview);
-
-    remove_view(m_dialog_relationships_overview);
-    delete m_dialog_relationships_overview;
-    m_dialog_relationships_overview = 0;
+    m_window_relationships_overview->show();
   }
 }
 
@@ -1601,6 +1637,12 @@ void Frame_Glom::do_menu_developer_relationships(Gtk::Window& parent, const Glib
   if(!m_pDialog_Relationships)
   {
     Utils::get_glade_widget_derived_with_warning(m_pDialog_Relationships);
+    if(!m_pDialog_Relationships)
+    {
+      std::cerr << G_STRFUNC << ": m_pDialog_Relationships is null." << std::cerr;
+      return;
+    }
+    
     m_pDialog_Relationships->set_title("Relationships");
     m_pDialog_Relationships->signal_hide().connect( sigc::mem_fun(*this, &Frame_Glom::on_developer_dialog_hide));
     add_view(m_pDialog_Relationships); //Also a composite view.
@@ -1665,11 +1707,23 @@ void Frame_Glom::on_menu_developer_reports()
   if(!m_pBox_Reports)
   {
     Utils::get_glade_child_widget_derived_with_warning(m_pBox_Reports);
+    if(!m_pBox_Reports)
+    {
+      std::cerr << G_STRFUNC << ": m_pBox_Reports is null." << std::cerr;
+      return;
+    }
+
     m_pDialog_Reports = new Window_BoxHolder(m_pBox_Reports);
     m_pDialog_Reports->set_transient_for(*(get_app_window()));
     m_pDialog_Reports->set_title(_("Reports"));
 
     Utils::get_glade_widget_derived_with_warning(m_pDialogLayoutReport);
+    if(!m_pDialogLayoutReport)
+    {
+      std::cerr << G_STRFUNC << ": m_pDialogLayoutReport is null." << std::endl;
+      return;
+    }
+
     add_view(m_pDialogLayoutReport);
     m_pDialogLayoutReport->set_transient_for(*(get_app_window()));
     m_pDialogLayoutReport->signal_hide().connect( sigc::mem_fun(*this, &Frame_Glom::on_dialog_layout_report_hide) );
@@ -1695,6 +1749,12 @@ void Frame_Glom::on_menu_developer_print_layouts()
   if(!m_pBox_PrintLayouts)
   {
     Utils::get_glade_child_widget_derived_with_warning(m_pBox_PrintLayouts);
+    if(!m_pBox_PrintLayouts)
+    {
+      std::cerr << G_STRFUNC << ": m_pBox_PrintLayouts is null." << std::endl;
+      return;
+    }
+
     m_pDialog_PrintLayouts = new Window_BoxHolder(m_pBox_PrintLayouts);
 
     m_pDialog_PrintLayouts->set_transient_for(*get_app_window());
@@ -1739,16 +1799,54 @@ void Frame_Glom::on_box_reports_selected(const Glib::ustring& report_name)
   }
 }
 
+void Frame_Glom::add_window_to_app(Gtk::ApplicationWindow* window)
+{
+  if(!window)
+  {
+    std::cerr << G_STRFUNC << ": window is null." << std::endl;
+    return;
+  }
 
+  Gtk::Window* app_window = get_app_window();
+  if(!app_window)
+  {
+    std::cerr << G_STRFUNC << ": app_window is null" << std::endl;
+    return;
+  }
+
+  //This probably lets the GtkApplication know about the window's actions, which might be useful.
+  Glib::RefPtr<Gtk::Application> app = app_window->get_application();
+  if(app)
+    app->add_window(*window);
+  else
+  {
+    std::cerr << G_STRFUNC << ": app is null." << std::endl;
+  }
+}
 
 void Frame_Glom::on_box_print_layouts_selected(const Glib::ustring& print_layout_name)
 {
+  Gtk::Window* app_window = get_app_window();
+  if(!app_window)
+  {
+    std::cerr << G_STRFUNC << ": app_window is null" << std::endl;
+    return;
+  }
+
   //Create the dialog if necessary:
   if(!m_pDialogLayoutPrint)
   {
     Utils::get_glade_widget_derived_with_warning(m_pDialogLayoutPrint);
+    if(!m_pDialogLayoutPrint)
+    {
+      std::cerr << G_STRFUNC << ": m_pDialogLayoutPrint is null" << std::endl;
+      return;
+    }
+
     add_view(m_pDialogLayoutPrint);
     m_pDialogLayoutPrint->signal_hide().connect( sigc::mem_fun(*this, &Frame_Glom::on_dialog_layout_print_hide) );
+
+    add_window_to_app(m_pDialogLayoutPrint);
   }
 
   m_pDialog_PrintLayouts->hide();
@@ -1756,8 +1854,10 @@ void Frame_Glom::on_box_print_layouts_selected(const Glib::ustring& print_layout
   sharedptr<PrintLayout> print_layout = get_document()->get_print_layout(m_table_name, print_layout_name);
   if(print_layout)
   {
-    m_pDialogLayoutPrint->set_transient_for(*get_app_window());
+    m_pDialogLayoutPrint->set_transient_for(*app_window);
+
     m_pDialogLayoutPrint->set_print_layout(m_table_name, print_layout);
+
     m_pDialogLayoutPrint->show();
   }
 }
@@ -1772,8 +1872,8 @@ void Frame_Glom::on_developer_dialog_hide()
     m_dialog_addrelatedtable->set_fields(m_table_name);
 
   //Update the display. TODO: Shouldn't this happen automatically via the view?
-  if(m_dialog_relationships_overview)
-    m_dialog_relationships_overview->load_from_document();
+  if(m_window_relationships_overview)
+    m_window_relationships_overview->load_from_document();
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
@@ -1897,6 +1997,12 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
   if(!m_pDialogConnection)
   {
     Utils::get_glade_widget_derived_with_warning(m_pDialogConnection);
+    if(!m_pDialogConnection)
+    {
+      std::cerr << G_STRFUNC << ": m_pBox_Reports is null." << std::cerr;
+      return false;
+    }
+
     add_view(m_pDialogConnection); //Also a composite view.
   }
 
@@ -2176,6 +2282,12 @@ bool Frame_Glom::connection_request_password_and_attempt(bool& database_not_foun
     m_pDialogConnection = 0;
 
     Utils::get_glade_widget_derived_with_warning(m_pDialogConnection);
+    if(!m_pDialogConnection)
+    {
+      std::cerr << G_STRFUNC << ": m_pDialogConnection is null." << std::endl;
+      return false;
+    }
+
     add_view(m_pDialogConnection); //Also a composite view.
 
     m_pDialogConnection->load_from_document(); //Get good defaults.
@@ -2281,6 +2393,12 @@ bool Frame_Glom::create_database(const Glib::ustring& database_name, const Glib:
     //Tell the user:
     Gtk::Dialog* dialog = 0;
     Utils::get_glade_widget_with_warning("glom_developer.glade", "dialog_error_create_database", dialog);
+    if(!dialog)
+    {
+      std::cerr << G_STRFUNC << ": dialog is null." << std::cerr;
+      return false;
+    }
+
     dialog->set_transient_for(*pWindowApp);
     Glom::Utils::dialog_run_with_help(dialog, "dialog_error_create_database");
     delete dialog;
@@ -2422,7 +2540,7 @@ void Frame_Glom::on_dialog_tables_hide()
   }
 }
 
-void Frame_Glom::on_notebook_data_switch_page(Gtk::Widget* /* page */, guint /* page_num */)
+void Frame_Glom::on_notebook_data_switch_page(Gtk::Widget* /* page */)
 {
   //Refill this menu, because it depends on whether list or details are visible:
   AppWindow* pApp = dynamic_cast<AppWindow*>(get_app_window());
@@ -2448,14 +2566,15 @@ void Frame_Glom::on_notebook_data_record_selection_changed()
     pApp->enable_menu_print_layouts_details(something_selected);  
 }
 
-void Frame_Glom::update_records_count()
+gulong Frame_Glom::update_records_count()
 {
   //Get the number of records available and the number found,
-  //and all the user to find all if necessary.
+  //and allow the user to find all if necessary.
 
   gulong count_all = 0;
   gulong count_found = 0;
   m_Notebook_Data.get_record_counts(count_all, count_found);
+  //std::cout << G_STRFUNC << ": count_all=" << count_all << ", count_found=" << count_found << std::endl;
 
   std::string str_count_all, str_count_found;
 
@@ -2485,6 +2604,7 @@ void Frame_Glom::update_records_count()
   m_Label_RecordsCount.set_text(str_count_all);
   m_Label_FoundCount.set_text(str_count_found);
 
+  return count_found;
 }
 
 void Frame_Glom::on_button_find_all()
