@@ -42,6 +42,7 @@
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
 #include "dialog_connection.h"
+#include <gtkmm/applicationwindow.h>
 #include <libglom/utils.h>
 
 #include "mode_data/box_data_list_related.h" //only for m_HackToFixLinkerError.
@@ -53,7 +54,7 @@ namespace Glom
 class Dialog_Layout_Report;
 class Window_PrintLayout_Edit;
 class Dialog_AddRelatedTable;
-class Dialog_RelationshipsOverview;
+class Window_RelationshipsOverview;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
 class Frame_Glom :
@@ -86,7 +87,15 @@ public:
   bool attempt_toggle_shared(bool shared);
   void on_menu_file_print();
 
-  void on_menu_Edit_Find();
+  /** Show the widgets for find mode.
+   * It is up to the caller to indicate in the menu that find mode is active.
+   */
+  void set_mode_find();
+
+  /** Show the widgets for data mode.
+   * It is up to the caller to indicate in the menu that find mode is not active.
+   */
+  void set_mode_data();
   
   void on_menu_add_record();
 
@@ -178,9 +187,7 @@ public:
    */
   void show_table(const Glib::ustring& table_name, const Gnome::Gda::Value& primary_key_value_for_details = Gnome::Gda::Value());
 
-protected:
-
-
+private:
 
   //virtual void set_document(Document* pDocument); //override
 
@@ -210,16 +217,20 @@ protected:
   Gtk::Window* get_app_window();
   const Gtk::Window* get_app_window() const;
 
-  void update_records_count();
+  void add_window_to_app(Gtk::ApplicationWindow* window);
+
+  /** Show the number of records in the table, and the number found, in the UI.
+   * @result The number of records found, for convenience for the caller.
+   */
+  gulong update_records_count();
 
   void alert_no_table();
 
-private:
   //Signal handlers:
   void on_notebook_find_criteria(const Gnome::Gda::SqlExpr& where_clause);
   void on_button_quickfind();
   void on_button_find_all();
-  void on_notebook_data_switch_page(Gtk::Widget* page, guint page_num);
+  void on_notebook_data_switch_page(Gtk::Widget* page);
   void on_notebook_data_record_details_requested(const Glib::ustring& table_name, Gnome::Gda::Value primary_key_value);
   void on_userlevel_changed(AppState::userlevels userlevel);
 
@@ -280,7 +291,7 @@ private:
   Dialog_Fields* m_pDialog_Fields;
   Dialog_Relationships* m_pDialog_Relationships;
   Dialog_AddRelatedTable* m_dialog_addrelatedtable;
-  Dialog_RelationshipsOverview* m_dialog_relationships_overview;
+  Window_RelationshipsOverview* m_window_relationships_overview;
 
 #endif //GLOM_ENABLE_CLIENT_ONLY
 
