@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
-71 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+71 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 // For instance:
@@ -82,7 +82,7 @@ int main(int argc, char* argv[])
     //https://bugzilla.gnome.org/show_bug.cgi?id=619445
     //This should tell us what the problem is:
     std::cerr << G_STRFUNC << ": exception from std::locale::global(std::locale(\"\")): " << ex.what() << std::endl;
-    std::cerr << "  This can happen if the locale is not properly installed or configured." << std::endl;
+    std::cerr << G_STRFUNC << ":   This can happen if the locale is not properly installed or configured." << std::endl;
   }
 
   
@@ -142,7 +142,7 @@ int main(int argc, char* argv[])
   if(!file_input->query_exists())
   {
     std::cerr << _("The Glom file does not exist.") << std::endl;
-    std::cerr << "uri: " << input_uri << std::endl;
+    std::cerr << G_STRFUNC << ": uri: " << input_uri << std::endl;
 
     std::cerr << std::endl << context.get_help() << std::endl;
     return EXIT_FAILURE;
@@ -185,7 +185,7 @@ int main(int argc, char* argv[])
 
   if(!test)
   {
-    std::cerr << "Document::load() failed with failure_code=" << failure_code << std::endl;
+    std::cerr << G_STRFUNC << ": Document::load() failed with failure_code=" << failure_code << std::endl;
     return EXIT_FAILURE;
   }
 
