@@ -144,7 +144,7 @@ Glib::RefPtr<Gnome::Gda::Connection> MySQL::attempt_connect(const Glib::ustring&
     if(temp_conn)
       std::cout << "  (Connection succeeds, but not to the specific database,  database=" << database << std::endl;
     else
-      std::cerr << "  (Could not connect even to the default database, database=" << database  << std::endl;
+      std::cerr << G_STRFUNC << ":   (Could not connect even to the default database, database=" << database  << std::endl;
 #endif
 
     throw ExceptionConnection(temp_conn ? ExceptionConnection::FAILURE_NO_DATABASE : ExceptionConnection::FAILURE_NO_SERVER);
@@ -389,7 +389,7 @@ bool MySQL::change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connectio
   catch(const Glib::Error& ex)
   {
     std::cerr << G_STRFUNC << "Exception: " << ex.what() << std::endl;
-    std::cerr << "  Reverting the transaction." << std::endl;
+    std::cerr << G_STRFUNC << ":   Reverting the transaction." << std::endl;
     
     try
     {
@@ -589,7 +589,7 @@ bool MySQL::save_backup(const SlotProgress& slot_progress, const Glib::ustring&
 
   if(!result)
   {
-    std::cerr << "Error while attempting to call pg_dump." << std::endl;
+    std::cerr << G_STRFUNC << ": Error while attempting to call pg_dump." << std::endl;
   }
 
   return result;
@@ -650,7 +650,7 @@ bool MySQL::convert_backup(const SlotProgress& slot_progress, const std::string&
 
   if(!result)
   {
-    std::cerr << "Error while attempting to call pg_restore." << std::endl;
+    std::cerr << G_STRFUNC << ": Error while attempting to call pg_restore." << std::endl;
   }
 
   return result;
@@ -808,7 +808,7 @@ bool MySQL::create_text_file(const std::string& file_uri, const std::string& con
     const Gio::Error& ex = *error.get();
 #endif
     // If the operation was not successful, print the error and abort
-    std::cerr << "ConnectionPool::create_text_file(): exception while creating file." << std::endl
+    std::cerr << G_STRFUNC << ": ConnectionPool::create_text_file(): exception while creating file." << std::endl
       << "  file uri:" << file_uri << std::endl
       << "  error:" << ex.what() << std::endl;
     return false; // print_error(ex, output_uri_string);
@@ -836,7 +836,7 @@ bool MySQL::create_text_file(const std::string& file_uri, const std::string& con
     Gio::Error& ex = *error.get();
 #endif
     // If the operation was not successful, print the error and abort
-    std::cerr << "ConnectionPool::create_text_file(): exception while writing to file." << std::endl
+    std::cerr << G_STRFUNC << ": ConnectionPool::create_text_file(): exception while writing to file." << std::endl
       << "  file uri:" << file_uri << std::endl
       << "  error:" << ex.what() << std::endl;
     return false; //print_error(ex, output_uri_string);
@@ -844,7 +844,7 @@ bool MySQL::create_text_file(const std::string& file_uri, const std::string& con
 
   if(bytes_written != (gssize)contents_size)
   {
-    std::cerr << "ConnectionPool::create_text_file(): not all bytes written when writing to file." << std::endl
+    std::cerr << G_STRFUNC << ": ConnectionPool::create_text_file(): not all bytes written when writing to file." << std::endl
       << "  file uri:" << file_uri << std::endl;
     return false;
   }
