@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include <libglom/translations_po.h>
@@ -122,7 +122,7 @@ static void on_gettextpo_xerror2 (int severity, po_message_t /* message1 */, con
 #else //HAVE_GETTEXTPO_XERROR
 static void on_gettextpo_error(int status, int errnum, const char * /* format */, ...)
 {
-  std::cerr << "gettext error (old libgettext-po API): status=" << status << ", errnum=" << errnum << std::endl;
+  std::cerr << G_STRFUNC << ": gettext error (old libgettext-po API): status=" << status << ", errnum=" << errnum << std::endl;
 }
 #endif //HAVE_GETTEXTPO_XERROR
 
