@@ -219,7 +219,7 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
     if(hbox_parent && add_open_button)
     {
       //Add a button for related record navigation:
-      m_button_go_to_details = Gtk::manage(new Gtk::Button(_("_Open")));
+      m_button_go_to_details = Gtk::manage(new Gtk::Button(_("_Open"), true));
       m_button_go_to_details->set_tooltip_text(_("Open the record identified by this ID, in the other table."));
       hbox_parent->pack_start(*m_button_go_to_details, Gtk::PACK_SHRINK);
       m_button_go_to_details->signal_clicked().connect(sigc::mem_fun(*this, &DataWidget::on_button_open_details));
@@ -229,12 +229,12 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
       //can generally not be edited via another table's layout.
       if(field_used_in_relationship_to_one)
       {
-        Gtk::Button* button_select = Gtk::manage(new Gtk::Button(_("_Find")));
+        Gtk::Button* button_select = Gtk::manage(new Gtk::Button(_("_Find"), true));
         button_select->set_tooltip_text(_("Enter search criteria to identify records in the other table, to choose an ID for this field."));
         hbox_parent->pack_start(*button_select, Gtk::PACK_SHRINK);
         button_select->signal_clicked().connect(sigc::mem_fun(*this, &DataWidget::on_button_select_id));
 
-        Gtk::Button* button_new = Gtk::manage(new Gtk::Button(_("_New")));
+        Gtk::Button* button_new = Gtk::manage(new Gtk::Button(_("_New"), true));
         button_new->set_tooltip_text(_("Enter details for a new record in the other table, then use its ID for this field."));
         hbox_parent->pack_start(*button_new, Gtk::PACK_SHRINK);
         button_new->signal_clicked().connect(sigc::mem_fun(*this, &DataWidget::on_button_new_id));
