@@ -14,23 +14,23 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "db_adddel_withbuttons.h"
 #include <glom/utils_ui.h>
 #include <gtkmm/buttonbox.h>
-#include <gtkmm/stock.h>
+#include <glibmm/i18n.h>
 
 namespace Glom
 {
 
 DbAddDel_WithButtons::DbAddDel_WithButtons()
 : m_ButtonBox(Gtk::ORIENTATION_HORIZONTAL),
-  m_Button_Del(Gtk::Stock::DELETE),
-  m_Button_Edit(Gtk::Stock::OPEN),
-  m_Button_Add(Gtk::Stock::ADD)
+  m_Button_Del(_("_Delete"), true),
+  m_Button_Edit(_("_Open"), true),
+  m_Button_Add(_("_Add"), true)
 {
   m_ButtonBox.set_layout(Gtk::BUTTONBOX_END);
   m_ButtonBox.set_spacing(Utils::DEFAULT_SPACING_SMALL);
@@ -92,7 +92,7 @@ void DbAddDel_WithButtons::set_allow_user_actions(bool bVal)
   setup_buttons();
 
   //Recreate popup menu with correct items:
-  setup_menu();
+  setup_menu(this);
 }
 
 void DbAddDel_WithButtons::setup_buttons()
