@@ -1,7 +1,7 @@
 
 /* Glom
  *
- * Copyright (C) 2001-2004 Murray Cumming
+ * Copyright (C) 2001-2013 Murray Cumming
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -15,13 +15,12 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "canvas_print_layout.h"
 #include <glom/utils_ui.h> //For bold_message()).
-#include <gtkmm/stock.h>
 #include <glom/mode_design/print_layouts/dialog_text_formatting.h>
 #include <glom/mode_design/layout/dialog_layout_list_related.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_line.h>
@@ -36,6 +35,8 @@
 #include <libglom/db_utils.h>
 
 #include <glom/glade_utils.h>
+#include <gtkmm/builder.h>
+#include <giomm/menu.h>
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -266,9 +267,7 @@ void Canvas_PrintLayout::fill_layout_group(const sharedptr<LayoutGroup>& group)
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 void Canvas_PrintLayout::setup_context_menu()
 {
-  m_context_menu_action_group = Gtk::ActionGroup::create();
-
-  m_context_menu_action_group->add(Gtk::Action::create("ContextMenu", "Context Menu") );
+  m_context_menu_action_group = Gio::SimpleActionGroup::create();
 
 /*
   Glib::RefPtr<Gtk::Action> action =  Gtk::Action::create("ContextInsertField", _("Field"));
@@ -280,41 +279,21 @@ void Canvas_PrintLayout::setup_context_menu()
     sigc::mem_fun(*this, &Canvas_PrintLayout::on_context_menu_insert_text) );
 */
 
-  m_action_edit = Gtk::Action::create("ContextMenuEdit", Gtk::Stock::EDIT);
-  m_context_menu_action_group->add(m_action_edit);
-  m_action_formatting =  Gtk::Action::create("ContextMenuFormatting", _("_Formatting"));
-  m_context_menu_action_group->add(m_action_formatting);
-  m_action_delete =  Gtk::Action::create("ContextMenuDelete", Gtk::Stock::DELETE);
-  m_context_menu_action_group->add(m_action_delete);
+  m_action_edit = m_context_menu_action_group->add_action("edit",
+    sigc::mem_fun(*this, &Canvas_PrintLayout::on_context_menu_edit));
+  m_action_formatting = m_context_menu_action_group->add_action("formatting",
+    sigc::mem_fun(*this, &Canvas_PrintLayout::on_context_menu_formatting));
+  m_action_delete = m_context_menu_action_group->add_action("delete",
+    sigc::mem_fun(*this, &Canvas_PrintLayout::on_context_menu_delete));
 
-  m_action_edit->signal_activate().connect( sigc::mem_fun(*this, &Canvas_PrintLayout::on_context_menu_edit) );
-  m_action_formatting->signal_activate().connect( sigc::mem_fun(*this, &Canvas_PrintLayout::on_context_menu_formatting) );
-  m_action_delete->signal_activate().connect( sigc::mem_fun(*this, &Canvas_PrintLayout::on_context_menu_delete) );
+  insert_action_group("context", m_context_menu_action_group);
 
-
-  m_context_menu_uimanager = Gtk::UIManager::create();
-  m_context_menu_uimanager->insert_action_group(m_context_menu_action_group);
-
-  try
-  {
-    Glib::ustring ui_info =
-      "<ui>"
-      "  <popup name='ContextMenu'>"
-      "    <menuitem action='ContextMenuEdit' />"
-      "    <menuitem action='ContextMenuFormatting' />"
-      "    <menuitem action='ContextMenuDelete' />"
-      "  </popup>"
-      "</ui>";
-
-    m_context_menu_uimanager->add_ui_from_string(ui_info);
-  }
-  catch(const Glib::Error& ex)
-  {
-    std::cerr << "building menus failed: " <<  ex.what();
-  }
-
-  //Get the menu:
-  m_context_menu = dynamic_cast<Gtk::Menu*>( m_context_menu_uimanager->get_widget("/ContextMenu") );
+  Glib::RefPtr<Gio::Menu> menu = Gio::Menu::create();
+  menu->append(_("_Edit"), "context.edit");
+  menu->append(_("_Formatting"), "context.formatting");
+  menu->append(_("_Delete"), "context.delete");
+  m_context_menu = new Gtk::Menu(menu);
+  m_context_menu->attach_to_widget(*this);
 }
 
 
@@ -333,7 +312,7 @@ void Canvas_PrintLayout::on_item_show_context_menu(guint button, guint32 activat
     enable_formatting = true;
   }
 
-  m_action_formatting->set_sensitive(enable_formatting);
+  m_action_formatting->set_enabled(enable_formatting);
 
   m_context_menu->popup(button, activate_time);
 }
