@@ -65,8 +65,9 @@ public:
   bool m_prevent_duplicates;
 };
 
-//For adding/deleting/selecting multi-columned lists of items.
-//This was also an abstraction layer against the strangeness of GtkSheet, though it now uses Gtk::TreeView instead.
+/** For adding/deleting/selecting multi-columned lists of items,
+ * allowing the user to add a new item by just entering data in an empty row at the end.
+ */
 class AddDel : public Gtk::Box
 {
 public:
@@ -198,6 +199,13 @@ public:
   typedef sigc::signal<void, const Gtk::TreeModel::iterator&> type_signal_user_requested_edit;
   type_signal_user_requested_edit signal_user_requested_edit();
 
+  //TODO: Add this to the menu?
+  /** This signal is emitted when the user presses the "extra" button.
+   * This sends the row number.
+   */
+  typedef sigc::signal<void, const Gtk::TreeModel::iterator&> type_signal_user_requested_extra;
+  type_signal_user_requested_extra signal_user_requested_extra();
+
   typedef sigc::signal<void> type_signal_user_requested_add;
   type_signal_user_requested_add signal_user_requested_add();
 
@@ -218,7 +226,18 @@ public:
    */
   Gtk::TreeModel::iterator get_last_row() const;
 
+
 protected:
+  void setup_menu(Gtk::Widget* widget);
+
+  guint get_count_hidden_system_columns();
+
+  void on_MenuPopup_activate_Edit();
+  void on_MenuPopup_activate_Delete();
+
+private:
+
+private:
   void init();
 
   /** Get an iterator to the blank row in which the user should add data for the new row.
@@ -226,7 +245,6 @@ protected:
    */
   Gtk::TreeModel::iterator add_item_placeholder(); //Return index of new row.
 
-  void setup_menu(Gtk::Widget* widget);
   Glib::ustring treeview_get_key(const Gtk::TreeModel::iterator& row);
 
   ///Add a blank row, or return the existing blank row if there already is one.
@@ -245,9 +263,6 @@ protected:
 
   bool on_button_press_event_Popup(GdkEventButton* event);
 
-  void on_MenuPopup_activate_Edit();
-  void on_MenuPopup_activate_Delete();
-
   void on_treeview_button_press_event(GdkEventButton* event);
 
   /** Set the menu to popup when the user right-clicks on the column titles.
@@ -265,7 +280,6 @@ protected:
   bool get_ignore_treeview_signals() const;
 
   bool get_view_column_index(guint model_column_index, guint& view_column_index);
-  guint get_count_hidden_system_columns();
 
   //The column_id is extra information that we can use later to discover what the column shows, even when columns have been reordered.
   guint treeview_append_column(const Glib::ustring& title, Gtk::CellRenderer& cellrenderer, const Gtk::TreeModelColumnBase& model_column, const Glib::ustring& column_id);
@@ -278,7 +292,10 @@ protected:
   //Member widgets:
   Gtk::ScrolledWindow m_ScrolledWindow;
 
+protected:
   Gtk::TreeView m_TreeView;
+
+private:
   Gtk::TreeModel::ColumnRecord m_ColumnRecord;
   Glib::RefPtr<Gtk::ListStore> m_refListStore;
   guint m_col_key; //The index of the hidden model column.
@@ -299,7 +316,10 @@ protected:
   Glib::RefPtr<Gio::SimpleActionGroup> m_refActionGroup;
   Glib::RefPtr<Gio::SimpleAction> m_refContextEdit, m_refContextDelete;
 
+protected:
   bool m_auto_add;
+
+private:
   bool m_allow_add;
   bool m_allow_delete;
   Glib::ustring m_prevent_duplicates_warning;
@@ -309,6 +329,7 @@ protected:
   type_signal_user_changed m_signal_user_changed;
   type_signal_user_requested_delete m_signal_user_requested_delete;
   type_signal_user_requested_edit m_signal_user_requested_edit;
+  type_signal_user_requested_extra m_signal_user_requested_extra;
   type_signal_user_requested_add m_signal_user_requested_add;
   type_signal_user_activated m_signal_user_activated;
   type_signal_user_reordered_columns m_signal_user_reordered_columns;
