@@ -262,7 +262,7 @@ Glib::RefPtr<Gdk::Pixbuf> Utils::get_pixbuf_for_gda_value(const Gnome::Gda::Valu
       catch(const Gdk::PixbufError& ex)
       {
         refPixbufLoader.reset();
-        std::cerr << "PixbufLoader::create failed: " << ex.what() << std::endl;
+        std::cerr << G_STRFUNC << ": PixbufLoader::create failed: " << ex.what() << std::endl;
       }
 
       if(refPixbufLoader)
@@ -522,15 +522,7 @@ void Utils::show_report_in_browser(const std::string& filepath, Gtk::Window* par
 
 std::string Utils::get_icon_path(const Glib::ustring& filename)
 {
-#ifdef G_OS_WIN32
-  gchar* basepath = g_win32_get_package_installation_directory_of_module(0);
-  const std::string result = Glib::build_filename(Glib::build_filename(basepath,
-      "share" G_DIR_SEPARATOR_S "glom" G_DIR_SEPARATOR_S "pixmaps"), filename);
-  g_free(basepath);
-  return result;
-#else
-  return Glib::build_filename(GLOM_PKGDATADIR G_DIR_SEPARATOR_S "pixmaps", filename);
-#endif
+  return  "/org/gnome/glom/data/icons/" + filename;
 }
 
 bool Utils::script_check_for_pygtk2_with_warning(const Glib::ustring& script, Gtk::Window* parent_window)
