@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
-71 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+71 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "tests/test_utils.h"
@@ -161,7 +161,7 @@ int main()
 
   if(!test)
   {
-    std::cerr << "Document::load() failed with failure_code=" << failure_code << std::endl;
+    std::cerr << G_STRFUNC << ": Document::load() failed with failure_code=" << failure_code << std::endl;
     return EXIT_FAILURE;
   }
 
@@ -273,7 +273,7 @@ int main()
   const std::vector<Glib::ustring> module_names = document.get_library_module_names();
   if(!module_names.empty()) //TODO: Test a document that actually has some?
   {
-    std::cerr << "Failure: Unexpected library module names." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Unexpected library module names." << std::endl;
     return false;
   }
 
@@ -283,32 +283,32 @@ int main()
     document.get_print_layout_names("contacts");
   if(print_layout_names.size() != 1)
   {
-    std::cerr << "Failure: Unexpected number of print layouts." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Unexpected number of print layouts." << std::endl;
     return false;
   }
 
   if(!contains(print_layout_names, "contact_details"))
   {
-    std::cerr << "Failure: Could not find the expected print layout name." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Could not find the expected print layout name." << std::endl;
     return false;
   }
   
   const Glom::sharedptr<const Glom::PrintLayout> print_layout = document.get_print_layout("contacts", "contact_details");
   if(!print_layout)
   {
-    std::cerr << "Failure: Could not get an expected print layout." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Could not get an expected print layout." << std::endl;
     return false;
   }
   
   if(print_layout->get_title_original() != "Contact Details")
   {
-    std::cerr << "Failure: Unexpected print layout title." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Unexpected print layout title." << std::endl;
     return false;
   }
   
   if(!print_layout->get_layout_group())
   {
-    std::cerr << "Failure: The print layout has no layout group." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: The print layout has no layout group." << std::endl;
     return false;
   }
 
@@ -317,32 +317,32 @@ int main()
     document.get_report_names("contacts");
   if(report_names.size() != 2)
   {
-    std::cerr << "Failure: Unexpected number of reports." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Unexpected number of reports." << std::endl;
     return false;
   }
 
   if(!contains(report_names, "by_country"))
   {
-    std::cerr << "Failure: Could not find the expected report name." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Could not find the expected report name." << std::endl;
     return false;
   }
 
   const Glom::sharedptr<const Glom::Report> report = document.get_report("contacts", "by_country_by_town");
   if(!report)
   {
-    std::cerr << "Failure: Could not get an expected report." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Could not get an expected report." << std::endl;
     return false;
   }
   
   if(report->get_title_original() != "By Country, By Town")
   {
-    std::cerr << "Failure: Unexpected report title." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Unexpected report title." << std::endl;
     return false;
   }
   
   if(!report->get_layout_group())
   {
-    std::cerr << "Failure: The report has no layout group." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: The report has no layout group." << std::endl;
     return false;
   }
 
@@ -367,13 +367,13 @@ int main()
   //Test navigation:
   if(!needs_navigation(document, "scenes", "location_id"))
   {
-    std::cerr << "Failure: DbUtils::layout_field_should_have_navigation() did not return the expected result." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: DbUtils::layout_field_should_have_navigation() did not return the expected result." << std::endl;
     return false;
   }
 
   if(needs_navigation(document, "scenes", "description"))
   {
-    std::cerr << "Failure: DbUtils::layout_field_should_have_navigation() did not return the expected result." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: DbUtils::layout_field_should_have_navigation() did not return the expected result." << std::endl;
     return false;
   }
 
@@ -386,7 +386,7 @@ int main()
     get_portal_from_details_layout(document, "scenes", portal_relationship_name);
   if(!portal)
   {
-    std::cerr << "Failure: Could not get the portal from the layout." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Could not get the portal from the layout." << std::endl;
     return false;
   }
 
@@ -396,19 +396,19 @@ int main()
 
   if(navigation_table_name != "characters")
   {
-    std::cerr << "Failure: get_suitable_table_to_view_details() returned an unexpected table name: " << navigation_table_name << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: get_suitable_table_to_view_details() returned an unexpected table name: " << navigation_table_name << std::endl;
     return false;
   }
 
   if(!navigation_relationship)
   {
-    std::cerr << "Failure: get_suitable_table_to_view_details() returned an empty navigation_relationship." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: get_suitable_table_to_view_details() returned an empty navigation_relationship." << std::endl;
     return false;
   }
 
   if(navigation_relationship->get_relationship_name() != "cast")
   {
-    std::cerr << "Failure: get_suitable_table_to_view_details() returned an unexpected navigation_relationship name: " << navigation_relationship->get_relationship_name() << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: get_suitable_table_to_view_details() returned an unexpected navigation_relationship name: " << navigation_relationship->get_relationship_name() << std::endl;
     return false;
   }
 
