@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
-71 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+71 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include <libglom/document/document.h>
@@ -57,7 +57,7 @@ int main()
 
   if(!test)
   {
-    std::cerr << "Document::load() failed with failure_code=" << failure_code << std::endl;
+    std::cerr << G_STRFUNC << ": Document::load() failed with failure_code=" << failure_code << std::endl;
     return EXIT_FAILURE;
   }
 
@@ -87,7 +87,7 @@ int main()
   g_assert(!query.empty());
   if(query.find("album_id") == Glib::ustring::npos)
   {
-    std::cerr << "Failed: The query did not contain an expected field name." << std::endl;
+    std::cerr << G_STRFUNC << ": Failed: The query did not contain an expected field name." << std::endl;
     return EXIT_FAILURE;
   }
 
