@@ -31,7 +31,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
 
   if(!(test_create_and_selfhost_new_database(document, hosting_mode, "test_db")))
   {
-    std::cerr << "test_create_and_selfhost_new_database() failed" << std::endl;
+    std::cerr << G_STRFUNC << ": test_create_and_selfhost_new_database() failed" << std::endl;
     return false;
   }
   
@@ -52,13 +52,13 @@ static bool test(Glom::Document::HostingMode hosting_mode)
       Glom::DbUtils::get_database_preferences(&document);
     if(prefs_out != prefs_in)
     {
-      std::cerr << "The System Preferences read out were not the same as those written." << std::endl;
+      std::cerr << G_STRFUNC << ": The System Preferences read out were not the same as those written." << std::endl;
       return false;
     }
   }
   catch(const Glom::ExceptionConnection& ex)
   {
-    std::cerr << "Exception: " << ex.what() << std::endl;
+    std::cerr << G_STRFUNC << ": Exception: " << ex.what() << std::endl;
     return false;
   }
 
