@@ -37,7 +37,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
     test_create_and_selfhost_from_example("example_smallbusiness.glom", document, hosting_mode);
   if(!recreated)
   {
-    std::cerr << "Recreation failed." << std::endl;
+    std::cerr << G_STRFUNC << ": Recreation failed." << std::endl;
     return false;
   }
   
@@ -45,7 +45,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
   Glom::sharedptr<const Glom::Field> primary_key_field = document.get_field_primary_key(table_name);
   if(!primary_key_field)
   {
-    std::cerr << "Failure: primary_key_field is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: primary_key_field is empty." << std::endl;
     return false;
   }
 
@@ -85,16 +85,16 @@ static bool test(Glom::Document::HostingMode hosting_mode)
 
   if(!test_check_numeric_value_type(hosting_mode, value))
   {
-    std::cerr << "Failure: The value has an unexpected type: " << 
+    std::cerr << G_STRFUNC << ": Failure: The value has an unexpected type: " << 
       g_type_name(value.get_value_type()) << std::endl;
     return false;
   }
 
   if(Glom::Conversions::get_double_for_gda_value_numeric(value) != 3.5f)
   {
-    std::cerr << "Failure: The value has an unexpected value: " << value.to_string() << " instead of 3.5" << std::endl;
-    std::cerr << "    value as string: " << value.to_string() << std::endl;
-    std::cerr << "    value GType: " << g_type_name(value.get_value_type()) << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: The value has an unexpected value: " << value.to_string() << " instead of 3.5" << std::endl;
+    std::cerr << G_STRFUNC << ":     value as string: " << value.to_string() << std::endl;
+    std::cerr << G_STRFUNC << ":     value GType: " << g_type_name(value.get_value_type()) << std::endl;
     return false;
   }
 
