@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
-71 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+71 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "tests/test_selfhosting_utils.h"
@@ -43,7 +43,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
       test_create_and_selfhost_from_example("example_music_collection.glom", document, hosting_mode);
     if(!recreated)
     {
-      std::cerr << "Recreation from the example failed." << std::endl;
+      std::cerr << G_STRFUNC << ": Recreation from the example failed." << std::endl;
       return false;
     }
 
@@ -53,7 +53,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
       sigc::ptr_fun(&on_backup_progress));
     if(backup_uri_tarball.empty())
     {
-      std::cerr << "Backup failed." << std::endl;
+      std::cerr << G_STRFUNC << ": Backup failed." << std::endl;
       return false;
     }
 
@@ -68,7 +68,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
         sigc::ptr_fun(&on_backup_progress));
     if(recreated_uri.empty())
     {
-      std::cerr << "Recreation from the example failed." << std::endl;
+      std::cerr << G_STRFUNC << ": Recreation from the example failed." << std::endl;
       return false;
     }
     
@@ -79,7 +79,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
       test_create_and_selfhost_from_uri(recreated_uri, document, hosting_mode);
     if(!recreated)
     {
-      std::cerr << "Recreation from the backup failed." << std::endl;
+      std::cerr << G_STRFUNC << ": Recreation from the backup failed." << std::endl;
       return false;
     }
 
@@ -88,7 +88,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
     /* TODO: Find out why this test fails, though it seems to work fine in the UI:
     if(!test_example_musiccollection_data(&document))
     {
-      std::cerr << "test_example_musiccollection_data() failed." << std::endl;
+      std::cerr << G_STRFUNC << ": test_example_musiccollection_data() failed." << std::endl;
       return false;
     }
     */
@@ -105,7 +105,7 @@ int main()
 
   if(!test(Glom::Document::HOSTING_MODE_POSTGRES_SELF))
   {
-    std::cerr << "Failed with PostgreSQL" << std::endl;
+    std::cerr << G_STRFUNC << ": Failed with PostgreSQL" << std::endl;
     test_selfhosting_cleanup();
     return EXIT_FAILURE;
   }
@@ -113,7 +113,7 @@ int main()
   /* TODO: Make this work with sqlite too:
   if(!test(Glom::Document::HOSTING_MODE_SQLITE))
   {
-    std::cerr << "Failed with SQLite" << std::endl;
+    std::cerr << G_STRFUNC << ": Failed with SQLite" << std::endl;
     test_selfhosting_cleanup();
     return EXIT_FAILURE;
   }
